summaryrefslogtreecommitdiff
path: root/addons/web/static/src/js/chrome.js
diff options
context:
space:
mode:
authorRaphael Collet <rco@openerp.com>2015-01-21 11:29:05 +0100
committerRaphael Collet <rco@openerp.com>2015-01-21 11:29:05 +0100
commit592f1cd229a7ffd5ca9280cea6c035f0e36db59c (patch)
tree07f48f581647a1bdc49e8d1ea35cd34e6a82db9c /addons/web/static/src/js/chrome.js
parent37e85a1e3520317e58f66daa8f58ecd833bd1208 (diff)
parent431f8de815bd87a20da867c88a13baf7104005e7 (diff)
Merge pull request #4676 from odoo-dev/8.0-speedup_loading-rco
[IMP] models: speedup registry loading (25% less time) The field setup on models is improved: only new-api fields are determined when building the model's class; the final _columns dict is derived from the fields once they are set up. This avoids setting up fields and columns at the same time, and finally overriding columns with the result of field setup. This branch also fixes the model setup in general: with the former code, a model could be introspected while it was only partially set up, and not all its fields were known. It incidentally fixes the "loss" of parameter partial that is necessary when loading custom fields. And during a partial setup, one2many custom fields are not introduced if their counterparts (model and many2one field) are not ready.
Diffstat (limited to 'addons/web/static/src/js/chrome.js')
0 files changed, 0 insertions, 0 deletions